<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet 
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:xs="http://www.w3.org/2001/XMLSchema"
  xmlns:funkce="http://www.kiv.zcu.cz/~herout/XSLTfunkce"
  xmlns:saxon="http://saxon.sf.net/"
  extension-element-prefixes="saxon"
  exclude-result-prefixes="xs funkce"
  version="2.0">

  <xsl:output method="text" 
              encoding="UTF-8"/>

  <xsl:variable name="jmenoCisZbozi" 
                select="'ciselnik-zbozi.xml'"/>
  <xsl:variable name="jmenoCisKurzu" 
                select="'ciselnik-kurzu-men.xml'"/>

  <xsl:function name="funkce:nactiDokument" 
                as="document-node()">
    <xsl:param name="jmeno" as="xs:string"/>
    <xsl:choose>
      <xsl:when test="doc-available($jmeno)">
        <xsl:sequence select="doc($jmeno)"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:message terminate="yes">
          <xsl:value-of select="$jmeno"/> - soubor nenalezen 
        </xsl:message>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:function>

  <xsl:variable name="cisZbozi" 
    select="funkce:nactiDokument($jmenoCisZbozi)"/>
  <xsl:variable name="cisKurzu" 
    select="funkce:nactiDokument($jmenoCisKurzu)"/>

  <xsl:variable name="celkovaCenaCZK" 
                select="0" saxon:assignable="yes"/>
  
  <xsl:template match="/pokladna">
    <xsl:text>Nákup ze dne </xsl:text>
    <xsl:value-of select="substring(string(current-date()),1,10)"/>
<!--        <xsl:value-of select="current-date()"/>-->
        
    <xsl:apply-templates select="polozka"/>
        
    <xsl:text>&#xA;Celková cena: </xsl:text>
    <xsl:value-of select="$celkovaCenaCZK"/>
    <xsl:text> CZK</xsl:text>
  </xsl:template>

  <xsl:template match="polozka">
    <xsl:variable name="varPolozka" select="."/>
    <xsl:text>&#xA;</xsl:text>
    <xsl:for-each select="$cisZbozi/ciselnik/zbozi">
      <xsl:if test="@id = $varPolozka/@idZbozi">
        <xsl:call-template name="vypis">
          <xsl:with-param name="polozka" select="$varPolozka"/>
          <xsl:with-param name="zbozi" select="."/>
        </xsl:call-template>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>

  <xsl:template name="vypis">
    <xsl:param name="polozka"/>
    <xsl:param name="zbozi"/>
    <xsl:value-of select="$zbozi/nazev"/>
    <xsl:text>: </xsl:text>
    <xsl:value-of select="$polozka/mnozstvi"/>
    <xsl:text> [</xsl:text>
    <xsl:value-of select="$polozka/mnozstvi/@jednotka"/>
    <xsl:text>] po </xsl:text>
    <xsl:value-of select="$zbozi/jednotkovaCena"/>
    <xsl:text> </xsl:text>
    <xsl:value-of select="$zbozi/jednotkovaCena/@mena"/>
    <xsl:text> za </xsl:text>
    <xsl:call-template name="cenaCZK">
      <xsl:with-param name="zkrMeny" 
        select="$zbozi/jednotkovaCena/@mena"/>
      <xsl:with-param name="cena" 
        select="$zbozi/jednotkovaCena * $polozka/mnozstvi"/>
    </xsl:call-template>
  </xsl:template>

  <xsl:template name="cenaCZK">
    <xsl:param name="zkrMeny"/>
    <xsl:param name="cena"/>
    <xsl:for-each select="$cisKurzu/kurzyMen/mena">
      <xsl:if test="@zkratka = $zkrMeny">
        <xsl:variable name="pom" 
                      select="number($cena * text())"/>
        <xsl:value-of select="$pom"/>
        <xsl:text> CZK</xsl:text>
        <saxon:assign name="celkovaCenaCZK" 
                      select="$celkovaCenaCZK + $pom"/>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>

</xsl:stylesheet>
